/* Copyright (C) 2003 David Fries <dfries@mail.win.org>
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation
 * $Id: OpenEXRWriter.cc,v 1.4 2003/12/15 04:13:39 david Exp $
 */

/* The goal of this program is to provide a loadable library so the base
 * merging program can write ppm files without having OpenEXR installed
 * on the computer and yet still write OpenEXR if this library is available.
 */

#include <ImfOutputFile.h>
#include <ImfRgbaFile.h>
#include <ImfStringAttribute.h>
#include <ImfArray.h>

using namespace Imf;
//using namespace Imath;

// the data format is, red, green, blue
extern "C"{ // this way we don't deal with C++ mangling
void WriteEXRImage(const char *outfile, unsigned short *data, int incount,
	int width, int height)
{
	Array2D<Rgba> fpixels(height, width);
	struct Crgb {unsigned short red, green, blue;};
	Crgb *pixel = (Crgb*)data;
	float imageCount = incount;

	int row;
	for(int y=0; y<height; y++)
	{
		row = y*width;
		for(int x=0; x<width; x++)
		{
			Rgba &p=fpixels[y][x];
			Crgb &tmp =pixel[row+x];
			p.r = tmp.red/imageCount/255.0;
			p.g = tmp.green/imageCount/255.0;
			p.b = tmp.blue/imageCount/255.0;
			p.a = 1;
		}
	}
	RgbaOutputFile file(outfile, width, height, WRITE_RGBA);
	file.setFrameBuffer( &fpixels[0][0], 1, width);
	file.writePixels(height);
}
}
